package com.bonus.canteen.core.alloc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.alloc.domain.AllocStall;
import com.bonus.canteen.core.alloc.service.IAllocStallService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 档口信息Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "档口信息接口")
@RestController
@RequestMapping("/alloc_stall")
public class AllocStallController extends BaseController {
    @Autowired
    private IAllocStallService allocStallService;

    /**
     * 查询档口信息列表
     */
    @ApiOperation(value = "查询档口信息列表")
    //@RequiresPermissions("alloc:stall:list")
    @GetMapping("/list")
    public TableDataInfo list(AllocStall allocStall) {
        if (allocStall.isPagenation()) {
            startPage();
        }
        List<AllocStall> list = allocStallService.selectAllocStallList(allocStall);
        return getDataTable(list);
    }

    /**
     * 导出档口信息列表
     */
    @ApiOperation(value = "导出档口信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:stall:export")
    @SysLog(title = "档口信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出档口信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AllocStall allocStall) {
        List<AllocStall> list = allocStallService.selectAllocStallList(allocStall);
        ExcelUtil<AllocStall> util = new ExcelUtil<AllocStall>(AllocStall.class);
        util.exportExcel(response, list, "档口信息数据");
    }

    /**
     * 获取档口信息详细信息
     */
    @ApiOperation(value = "获取档口信息详细信息")
    //@RequiresPermissions("alloc:stall:query")
    @GetMapping(value = "/{stallId}")
    public AjaxResult getInfo(@PathVariable("stallId") Long stallId) {
        return success(allocStallService.selectAllocStallByStallId(stallId));
    }

    /**
     * 新增档口信息
     */
    @ApiOperation(value = "新增档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:stall:add")
    @SysLog(title = "档口信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增档口信息")
    @PostMapping
    public AjaxResult add(@RequestBody AllocStall allocStall) {
        try {
            return toAjax(allocStallService.insertAllocStall(allocStall));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改档口信息
     */
    @ApiOperation(value = "修改档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:stall:edit")
    @SysLog(title = "档口信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改档口信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AllocStall allocStall) {
        try {
            return toAjax(allocStallService.updateAllocStall(allocStall));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除档口信息
     */
    @ApiOperation(value = "删除档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:stall:remove")
    @SysLog(title = "档口信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除档口信息")
	@PostMapping("/del/{stallIds}")
    public AjaxResult remove(@PathVariable Long[] stallIds) {
        return toAjax(allocStallService.deleteAllocStallByStallIds(stallIds));
    }
}
